summaryrefslogtreecommitdiffstats
path: root/kmail/objecttreeparser.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/objecttreeparser.cpp')
-rw-r--r--kmail/objecttreeparser.cpp22
1 files changed, 11 insertions, 11 deletions
diff --git a/kmail/objecttreeparser.cpp b/kmail/objecttreeparser.cpp
index d8b98f24..132dc058 100644
--- a/kmail/objecttreeparser.cpp
+++ b/kmail/objecttreeparser.cpp
@@ -272,7 +272,7 @@ namespace KMail {
ProcessResult processResult;
if ( mReader ) {
- htmlWriter()->queue( TQString::fromLatin1("<a name=\"att%1\"/>").arg( node->nodeId() ) );
+ htmlWriter()->queue( TQString::tqfromLatin1("<a name=\"att%1\"/>").arg( node->nodeId() ) );
}
if ( const Interface::BodyPartFormatter * formatter
@@ -461,7 +461,7 @@ namespace KMail {
dumpToFile( "dat_01_reader_signedtext_before_canonicalization",
cleartext.data(), cleartext.length() );
// replace simple LFs by CRLSs
// according to RfC 2633, 3.1.1 Canonicalization
//kdDebug(5006) << "Converting LF to CRLF (see RfC 2633, 3.1.1 Canonicalization)" << endl;
cleartext = Util::lf2crlf( cleartext );
@@ -829,7 +829,7 @@ bool ObjectTreeParser::okDecryptMIME( partNode& data,
if ( mReader )
emit mReader->noDrag(); // in case pineentry pops up, don't let kmheaders start a drag afterwards
// Check whether the memento contains a result from last time:
const DecryptVerifyBodyPartMemento * m
= dynamic_cast<DecryptVerifyBodyPartMemento*>( data.bodyPartMemento( "decryptverify" ) );
if ( !m ) {
@@ -936,7 +936,7 @@ bool ObjectTreeParser::okDecryptMIME( partNode& data,
}
//static
- bool ObjectTreeParser::containsExternalReferences( const TQCString & str )
+ bool ObjectTreeParser::tqcontainsExternalReferences( const TQCString & str )
{
TQRegExp httpRegExp("(\\\"|\\\'|url\\s*\\(\\s*)http[s]?:");
int httpPos = str.find( httpRegExp, 0 );
@@ -990,12 +990,12 @@ bool ObjectTreeParser::okDecryptMIME( partNode& data,
// ---Sven's strip </BODY> and </HTML> from end of attachment end-
// Show the "external references" warning (with possibility to load
// external references only if loading external references is disabled
// and the HTML code contains obvious external references). For
// messages where the external references are obfuscated the user won't
// have an easy way to load them but that shouldn't be a problem
// because only spam contains obfuscated external references.
if ( !mReader->htmlLoadExternal() &&
- containsExternalReferences( cstr ) ) {
+ tqcontainsExternalReferences( cstr ) ) {
htmlWriter()->queue( "<div class=\"htmlWarn\">\n" );
htmlWriter()->queue( i18n("<b>Note:</b> This HTML message may contain external "
"references to images etc. For security/privacy reasons "
@@ -1357,7 +1357,7 @@ namespace KMail {
const Kleo::CryptoBackend::Protocol * useThisCryptProto = 0;
/*
- ATTENTION: This code is to be replaced by the new 'auto-detect' feature. --------------------------------------
+ ATTENTION: This code is to be tqreplaced by the new 'auto-detect' feature. --------------------------------------
*/
partNode * data = child->findType( DwMime::kTypeApplication,
DwMime::kSubtypeOctetStream, false, true );
@@ -1559,7 +1559,7 @@ namespace KMail {
writeDeferredDecryptionBlock();
} else {
/*
- ATTENTION: This code is to be replaced by the planned 'auto-detect' feature.
+ ATTENTION: This code is to be tqreplaced by the planned 'auto-detect' feature.
*/
PartMetaData messagePart;
setCryptoProtocol( Kleo::CryptoBackendFactory::instance()->openpgp() );
@@ -2795,7 +2795,7 @@ void ObjectTreeParser::writeBodyStr( const TQCString& aStr, const TQTextCodec *a
bool goodSignature = false;
Kpgp::Module* pgp = Kpgp::Module::getKpgp();
assert(pgp != 0);
- bool isPgpMessage = false; // true if the message contains at least one
+ bool isPgpMessage = false; // true if the message tqcontains at least one
// PGP MESSAGE or one PGP SIGNED MESSAGE block
TQString dir = ( TQApplication::reverseLayout() ? "rtl" : "ltr" );
TQString headerStr = TQString("<div dir=\"%1\">").arg(dir);
@@ -3083,7 +3083,7 @@ TQString ObjectTreeParser::quotedHTML( const TQString& s, bool decorate )
{
// don't write empty <div ...></div> blocks (they have zero height)
// ignore ^M DOS linebreaks
- if( !line.replace('\015', "").isEmpty() )
+ if( !line.tqreplace('\015', "").isEmpty() )
{
htmlStr +=TQString( "<div dir=\"%1\">" ).arg( line.isRightToLeft() ? "rtl":"ltr" );
htmlStr += LinkLocator::convertToHtml( line, convertFlags );
@@ -461,7 +461,7 @@ namespace KMail {
dumpToFile( "dat_01_reader_signedtext_before_canonicalization",
cleartext.data(), cleartext.length() );
- // replace simple LFs by CRLSs
+ // tqreplace simple LFs by CRLSs
// according to RfC 2633, 3.1.1 Canonicalization
//kdDebug(5006) << "Converting LF to CRLF (see RfC 2633, 3.1.1 Canonicalization)" << endl;
@@ -829,7 +829,7 @@ bool ObjectTreeParser::okDecryptMIME( partNode& data,
if ( mReader )
emit mReader->noDrag(); // in case pineentry pops up, don't let kmheaders start a drag afterwards
- // Check whether the memento contains a result from last time:
+ // Check whether the memento tqcontains a result from last time:
const DecryptVerifyBodyPartMemento * m
= dynamic_cast<DecryptVerifyBodyPartMemento*>( data.bodyPartMemento( "decryptverify" ) );
@@ -990,12 +990,12 @@ bool ObjectTreeParser::okDecryptMIME( partNode& data,
// Show the "external references" warning (with possibility to load
// external references only if loading external references is disabled
- // and the HTML code contains obvious external references). For
+ // and the HTML code tqcontains obvious external references). For
// messages where the external references are obfuscated the user won't
// have an easy way to load them but that shouldn't be a problem
@@ -990,12 +990,12 @@ bool ObjectTreeParser::okDecryptMIME( partNode& data,
// messages where the external references are obfuscated the user won't
// have an easy way to load them but that shouldn't be a problem
- // because only spam contains obfuscated external references.
+ // because only spam tqcontains obfuscated external references.
if ( !mReader->htmlLoadExternal() &&